@@ -25,7 +25,7 @@ class ShellUtils(object):
             Tuple containing git username and email.
 
         """
-        cls._log.info("Try read git user information.")
+        cls._log.debug("Try read git user information.")
 
         try:
             author = subprocess.check_output(
@@ -46,28 +46,41 @@ class ShellUtils(object):
         return author, email
 
     @classmethod
-    def run_project_install(cls, project_path):
-        """Run make install at provided project path.
+    def run_shell(cls, cmd, cwd=None, check=False, stdout=None, stderr=None):
+        """Run shell command without activated virtualenv.
 
-        If virtual env is activated, remove it from PATH in order to ensure make
-        install proper execution. For more information, see issue:
+        If virtual env is activated, remove it from PATH in order to ensure
+        command proper execution. For more information, see issue:
         https://github.com/rszamszur/fastapi-mvc/issues/37
 
         Args:
-            project_path(str): Project path in which execute make install.
+            cmd(list): Shell command to run.
+            cwd(str): Path under which proces should execute command. Defaults
+                to current working directory.
+            check(bool): If True raise a subprocess.CalledProcessError error
+                when a process returns non-zero exit status.
+            stdout(Union[None, int, IO[Any]]): Specify the executed program’s
+                standard output file handles.
+            stderr(Union[None, int, IO[Any]]): Specify the executed program’s
+                standard error file handles.
 
         Raises:
             subprocess.CalledProcessError: If spawned proces finishes with an
-                error.
+                error and check is True.
 
         """
-        cls._log.info(
-            "Run make install for project: {0:s}".format(project_path)
+        if not cwd:
+            cwd = os.getcwd()
+
+        cls._log.debug(
+            "Run shell command: {cmd} under path: {cwd}".format(
+                cmd=cmd, cwd=cwd
+            )
         )
         env = os.environ.copy()
 
         if "VIRTUAL_ENV" in env:
-            cls._log.info("Activated virtual env detected.")
+            cls._log.warning("Activated virtual env detected.")
 
             venv_path = "{venv}/bin".format(venv=env["VIRTUAL_ENV"])
             del env["VIRTUAL_ENV"]
@@ -75,7 +88,15 @@ class ShellUtils(object):
             env["PATH"] = env["PATH"].replace(venv_path, "").strip(":")
 
         try:
-            subprocess.run(["make", "install"], cwd=project_path, env=env)
+            process = subprocess.run(
+                cmd,
+                cwd=cwd,
+                env=env,
+                check=check,
+                stdout=stdout,
+                stderr=stderr,
+            )
+            return process
         except subprocess.CalledProcessError as ex:
             cls._log.exception(
                 "Proces finished with an exception.",
